"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getDistinctValues = void 0;
const lodash_1 = require("lodash");
/**
 * returns an array of all distinct values in a field (equality or $in)
 *
 * @param  {Any}  field   the right-hand side of a document field
 * @return {Boolean}      array of values for this field
 */
const getDistinctValues = (field) => {
    // field not present, return empty array
    if (field === undefined) {
        return [];
    }
    // field is object, could be a $in clause or a primitive value
    if ((0, lodash_1.isPlainObject)(field)) {
        if ((0, lodash_1.has)(field, '$in')) {
            return field.$in;
        }
    }
    // it is not a $in operator, return single value as array
    return [field];
};
exports.getDistinctValues = getDistinctValues;
//# sourceMappingURL=get-distinct-values.js.map