"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.hasDistinctValue = void 0;
const lodash_1 = require("lodash");
const bson_equal_1 = require("./bson-equal");
/**
 * Determines if a field in the query has a distinct value (equality or $in).
 *
 * @param  {Any}  field   the right-hand side of a document field
 * @param  {Any}  value   the value to check
 * @return {Boolean}      whether or not value is included in field
 */
const hasDistinctValue = (field, value) => {
    // field not present, add primitive value
    if (field === undefined) {
        return false;
    }
    // field is object, could be a $in clause or a primitive value
    if ((0, lodash_1.isPlainObject)(field)) {
        if ((0, lodash_1.has)(field, '$in')) {
            // check if $in array contains the value
            const inArray = field.$in;
            return (0, lodash_1.some)(inArray, (other) => {
                return (0, lodash_1.isEqualWith)(value, other, bson_equal_1.bsonEqual);
            });
        }
    }
    // it is not a $in operator, check value directly
    return (0, lodash_1.isEqualWith)(field, value, bson_equal_1.bsonEqual);
};
exports.hasDistinctValue = hasDistinctValue;
//# sourceMappingURL=has-distinct-value.js.map