/**
 * returns whether a value is fully or partially covered by a range,
 * specified with $gt(e)/$lt(e). Ranges can be open ended on either side,
 * and can also be single equality queries, e.g. {"field": 16}.
 *
 * @examples
 * inValueRange(15, {value: 15, dx: 0})                    => 'yes'
 * inValueRange({$gte: 15, $lt: 30}, {value: 20, dx: 5})   => 'yes'
 * inValueRange({$gte: 15, $lt: 30}, {value: 15, dx: 5})   => 'yes'
 * inValueRange(15, {value: 15, dx: 1})                    => 'partial'
 * inValueRange({$gt: 15, $lt: 30}, {value: 15, dx: 5})    => 'partial'
 * inValueRange({$gte: 15, $lt: 30}, {value: 20, dx: 20})  => 'partial'
 * inValueRange({$gte: 15, $lt: 30}, {value: 10, dx: 10})  => 'partial'
 * inValueRange({$gte: 15, $lt: 30}, {value: 10, dx: 5})   => 'partial'
 * inValueRange({$gt: 15, $lt: 30}, {value: 10, dx: 5})    => 'no'
 * inValueRange({$gte: 15, $lt: 30}, {value: 10, dx: 4})   => 'no'
 *
 * @param  {Object|number} field   the field value (range or number)
 * @param  {Object} d              object with a `value` and `dx` field if
 *                                 the value represents a binned range itself
 * @return {String}                'yes', 'partial', 'no'
 */
export declare const inValueRange: (field: any, d: {
    value: any;
    dx?: number;
    bson?: any;
}) => "yes" | "partial" | "no";
//# sourceMappingURL=in-value-range.d.ts.map